@@ -1,14 +1,17 @@
 import os
 import os.path as osp
+import yaml
 import json
 import shutil
 import sys
 import time
 import tempfile
+import subprocess
+import datetime
 from importlib import import_module
 from typing import Optional, Tuple, NoReturn
-import yaml
 from easydict import EasyDict
+from copy import deepcopy
 
 from ding.utils import deep_merge_dicts
 from ding.envs import get_env_cls, get_env_manager_cls, BaseEnvManager
@@ -307,6 +310,21 @@ env_config_template = dict(manager=dict(), )
 env_config_template = EasyDict(env_config_template)
 
 
+def save_project_state(exp_name: str) -> None:
+
+    def _fn(cmd: str):
+        return subprocess.run(cmd, shell=True, stdout=subprocess.PIPE).stdout.strip().decode("utf-8")
+
+    if subprocess.run("git status", shell=True, stderr=subprocess.PIPE).returncode == 0:
+        short_sha = _fn("git describe --always")
+        log = _fn("git log --stat -n 5")
+        diff = _fn("git diff")
+        with open(os.path.join(exp_name, "git_log.txt"), "w") as f:
+            f.write(short_sha + '\n\n' + log)
+        with open(os.path.join(exp_name, "git_diff.txt"), "w") as f:
+            f.write(diff)
+
+
 def compile_config(
         cfg: EasyDict,
         env_manager: type = None,
@@ -346,6 +364,7 @@ def compile_config(
     Returns:
         - cfg (:obj:`EasyDict`): Config after compiling
     """
+    cfg, create_cfg = deepcopy(cfg), deepcopy(create_cfg)
     if auto:
         assert create_cfg is not None
         # for compatibility
@@ -355,7 +374,11 @@ def compile_config(
             create_cfg.replay_buffer = EasyDict(dict(type='advanced'))
             buffer = AdvancedReplayBuffer
         if env is None:
-            env = get_env_cls(create_cfg.env)
+            if 'env' in create_cfg:
+                env = get_env_cls(create_cfg.env)
+            else:
+                env = None
+                create_cfg.env = {'type': 'ding_env_wrapper_generated'}
         if env_manager is None:
             env_manager = get_env_manager_cls(create_cfg.env_manager)
         if policy is None:
@@ -436,11 +459,13 @@ def compile_config(
     if 'exp_name' not in cfg:
         cfg.exp_name = 'default_experiment'
     if save_cfg:
-        if not os.path.exists(cfg.exp_name):
-            try:
-                os.mkdir(cfg.exp_name)
-            except FileExistsError:
-                pass
+        if os.path.exists(cfg.exp_name):
+            cfg.exp_name += datetime.datetime.now().strftime("_%y%m%d_%H%M%S")
+        try:
+            os.makedirs(cfg.exp_name)
+        except FileExistsError:
+            pass
+        save_project_state(cfg.exp_name)
         save_path = os.path.join(cfg.exp_name, save_path)
         save_config(cfg, save_path, save_formatted=True)
     return cfg
