@@ -1,8 +1,7 @@
-from typing import List, Optional, Union
+from typing import List, Optional, Union, Dict
 import gym
 import copy
 import numpy as np
-from numpy.lib.arraysetops import isin
 
 from ding.envs.common.common_function import affine_transform
 from ding.envs.env_wrappers import create_env_wrapper
@@ -69,7 +68,7 @@ class DingEnvWrapper(BaseEnv):
             self._env.seed(self._seed)
             self._action_space.seed(self._seed)
         obs = self._env.reset()
-        obs = to_ndarray(obs).astype(np.float32)
+        obs = to_ndarray(obs, np.float32)
         return obs
 
     # override
@@ -88,8 +87,8 @@ class DingEnvWrapper(BaseEnv):
         if self._cfg.get('act_scale', False):
             action = affine_transform(action, min_val=self._env.action_space.low, max_val=self._env.action_space.high)
         obs, rew, done, info = self._env.step(action)
-        obs = to_ndarray(obs).astype(np.float32)
-        rew = to_ndarray([rew]).astype(np.float32)
+        obs = to_ndarray(obs, np.float32)
+        rew = to_ndarray([rew], np.float32)
         return BaseEnvTimestep(obs, rew, done, info)
 
     def _judge_action_type(self, action: Union[np.ndarray, dict]) -> Union[np.ndarray, dict]:
@@ -127,19 +126,21 @@ class DingEnvWrapper(BaseEnv):
         return random_action
 
     def _wrap_env(self) -> None:
-        wrapper_cfgs = self._cfg.get('env_wrapper', None)
-        if wrapper_cfgs is None:
-            wrapper_cfgs = 'default'
+        # wrapper_cfgs: Union[str, List]
+        wrapper_cfgs = self._cfg.get('env_wrapper', 'default')
         if isinstance(wrapper_cfgs, str):
             wrapper_cfgs = get_default_wrappers(wrapper_cfgs, self._cfg.get('env_id', None))
+        # self._wrapper_cfgs: List[Union[Callable, Dict]]
         self._wrapper_cfgs = wrapper_cfgs
-        for wrapper_cfg in self._wrapper_cfgs:
-            if wrapper_cfg.get('disable', False):
-                continue
-            self._env = create_env_wrapper(self._env, wrapper_cfg)
+        for wrapper in self._wrapper_cfgs:
+            # wrapper: Union[Callable, Dict]
+            if isinstance(wrapper, Dict):
+                self._env = create_env_wrapper(self._env, wrapper)
+            else:  # Callable, such as lambda anonymous function
+                self._env = wrapper(self._env)
 
     def __repr__(self) -> str:
-        return "DI-engine Env({})".format(self._cfg.env_id)
+        return "DI-engine Env({}), generated by DingEnvWrapper".format(self._cfg.env_id)
 
     @staticmethod
     def create_collector_env_cfg(cfg: dict) -> List[dict]:
