@@ -7,6 +7,7 @@ import torch
 import treetensor.torch as ttorch
 from easydict import EasyDict
 from ding.envs import BaseEnvManager
+from ding.framework.context import OfflineRLContext
 from ding.policy import Policy
 from ding.data import Dataset, DataLoader
 from ding.framework import task
@@ -195,11 +196,14 @@ def interaction_evaluator(cfg: EasyDict, policy: Policy, env: BaseEnvManager) ->
         episode_reward = eval_monitor.get_episode_reward()
         eval_reward = np.mean(episode_reward)
         stop_flag = eval_reward >= cfg.env.stop_value and ctx.train_iter > 0
-        logging.info(
-            'Evaluation: Train Iter({})\tEnv Step({})\tEval Reward({:.3f})'.format(
-                ctx.train_iter, ctx.env_step, eval_reward
+        if isinstance(ctx, OfflineRLContext):
+            logging.info('Evaluation: Train Iter({})\tEval Reward({:.3f})'.format(ctx.train_iter, eval_reward))
+        else:
+            logging.info(
+                'Evaluation: Train Iter({})\tEnv Step({})\tEval Reward({:.3f})'.format(
+                    ctx.train_iter, ctx.env_step, eval_reward
+                )
             )
-        )
         ctx.last_eval_iter = ctx.train_iter
         ctx.eval_value = eval_reward
 
