@@ -1,8 +1,9 @@
 from typing import Dict, Any, Callable
 from collections import namedtuple
+from easydict import EasyDict
 import torch
+
 from ding.torch_utils import to_device
-import numpy as np
 import gym
 
 
@@ -34,23 +35,22 @@ class PolicyFactory:
             actions = {}
             for env_id in data:
                 if not isinstance(action_space, list):
-                    action = action_space.sample()
+                    action = torch.as_tensor(action_space.sample())
                     if isinstance(action_space, gym.spaces.MultiDiscrete):
                         action = [torch.LongTensor([v]) for v in action]
                     actions[env_id] = {'action': action}
                 elif 'global_state' in data[env_id].keys():
                     # for smac
-                    logit = np.ones_like(data[env_id]['action_mask'])
+                    logit = torch.ones_like(data[env_id]['action_mask'])
                     logit[data[env_id]['action_mask'] == 0.0] = -1e8
                     dist = torch.distributions.categorical.Categorical(logits=torch.Tensor(logit))
-                    actions[env_id] = {'action': np.array(dist.sample()), 'logit': np.array(logit)}
+                    actions[env_id] = {'action': dist.sample(), 'logit': torch.as_tensor(logit)}
                 else:
                     # for gfootball
                     actions[env_id] = {
-                        'action': np.array([action_space_agent.sample() for action_space_agent in action_space]),
-                        'logit': np.ones([len(action_space), action_space[0].n])
+                        'action': torch.as_tensor([action_space_agent.sample() for action_space_agent in action_space]),
+                        'logit': torch.ones([len(action_space), action_space[0].n])
                     }
-
             return actions
 
         def reset(*args, **kwargs) -> None:
@@ -64,3 +64,11 @@ class PolicyFactory:
             return random_collect_function(
                 forward, policy.process_transition, policy.get_train_sample, reset, policy.get_attribute
             )
+
+
+def get_random_policy(cfg: EasyDict, policy: 'Policy.collect_mode', env: 'BaseEnvManager'):  # noqa
+    if cfg.policy.get('transition_with_policy_data', False):
+        return policy
+    else:
+        action_space = env.action_space
+        return PolicyFactory.get_random_policy(policy, action_space=action_space)
