@@ -1,3 +1,4 @@
 from .collate_fn import diff_shape_collate, default_collate, default_decollate, timestep_collate, ttorch_collate
 from .dataloader import AsyncDataLoader
-from .dataset import NaiveRLDataset, D4RLDataset, HDF5Dataset, create_dataset, hdf5_save, offline_data_save_type
+from .dataset import NaiveRLDataset, D4RLDataset, HDF5Dataset, BCODataset, \
+    create_dataset, hdf5_save, offline_data_save_type
