@@ -19,6 +19,7 @@ DATASET_REGISTRY = Registry()
 SERIAL_EVALUATOR_REGISTRY = Registry()
 MQ_REGISTRY = Registry()
 WORLD_MODEL_REGISTRY = Registry()
+STOCHASTIC_OPTIMIZER_REGISTRY = Registry()
 
 registries = {
     'policy': POLICY_REGISTRY,
@@ -40,4 +41,5 @@ registries = {
     'serial_evaluator': SERIAL_EVALUATOR_REGISTRY,
     'message_queue': MQ_REGISTRY,
     'world_model': WORLD_MODEL_REGISTRY,
+    'stochastic_optimizer': STOCHASTIC_OPTIMIZER_REGISTRY,
 }
