@@ -33,15 +33,18 @@ def fps(env_manager: "BaseEnvManager") -> "int":
     Returns:
         - fps (:obj:`int`).
     '''
-    # env_ref is an gym environment
-    gym_env = env_manager.env_ref._env
-    if hasattr(gym_env, 'model'):
-        # mujoco
-        fps = 1 / gym_env.model.opt.timestep
-    elif hasattr(gym_env, 'env') and 'video.frames_per_second' in gym_env.env.metadata.keys():
-        # classic control
-        fps = gym_env.env.metadata['video.frames_per_second']
-    else:
-        # atari and other envs
-        fps = 30
-    return fps
+    try:
+        # env_ref is a ding gym environment
+        gym_env = env_manager.env_ref._env
+        if hasattr(gym_env, 'model'):
+            # mujoco
+            fps = 1 / gym_env.model.opt.timestep
+        elif hasattr(gym_env, 'env') and 'video.frames_per_second' in gym_env.env.metadata.keys():
+            # classic control
+            fps = gym_env.env.metadata['video.frames_per_second']
+        else:
+            # atari and other envs
+            fps = 30
+        return fps
+    except:
+        return 30
