@@ -7,7 +7,7 @@ from .episode_serial_collector import EpisodeSerialCollector
 from .battle_episode_serial_collector import BattleEpisodeSerialCollector
 from .battle_sample_serial_collector import BattleSampleSerialCollector
 
-from .base_serial_evaluator import ISerialEvaluator, VectorEvalMonitor
+from .base_serial_evaluator import ISerialEvaluator, VectorEvalMonitor, create_serial_evaluator
 from .interaction_serial_evaluator import InteractionSerialEvaluator
 from .battle_interaction_serial_evaluator import BattleInteractionSerialEvaluator
 from .metric_serial_evaluator import MetricSerialEvaluator, IMetric
