@@ -7,13 +7,12 @@ qbert_trex_ppo_config = dict(
         evaluator_env_num=8,
         n_evaluator_episode=8,
         stop_value=10000000000,
-        env_id='QbertNoFrameskip-v4',
+        env_id='Qbert-v4',
+        #'ALE/Qbert-v5' is available. But special setting is needed after gym make.
         frame_stack=4
     ),
     reward_model=dict(
         type='trex',
-        algo_for_model='ppo',
-        env_id='QbertNoFrameskip-v4',
         min_snippet_length=30,
         max_snippet_length=100,
         checkpoint_min=0,
