@@ -20,12 +20,7 @@ cartpole_ppopg_config = dict(
             learning_rate=0.001,
             entropy_weight=0.01,
         ),
-        collect=dict(
-            n_episode=160,
-            unroll_len=1,
-            discount_factor=0.9,
-            collector=dict(get_train_sample=True)
-        ),
+        collect=dict(n_episode=160, unroll_len=1, discount_factor=0.9, collector=dict(get_train_sample=True)),
         eval=dict(evaluator=dict(eval_freq=100, ), ),
     ),
 )
