@@ -1,2 +1,2 @@
 from .kaggle_5th_place_model import FootballKaggle5thPlaceModel
-from .rule_based_bot import FootballRuleBaseModel
\ No newline at end of file
+from .rule_based_bot_model import FootballRuleBaseModel
