@@ -38,22 +38,16 @@ class MujocoEnv(BaseEnv):
 
         self._num_agents = self.env_info['n_agents']
         self._agents = [i for i in range(self._num_agents)]
-        self._observation_space = gym.spaces.Dict({
-            'agent_state':
-                gym.spaces.Box(
-                    low=float("-inf"),
-                    high=float("inf"),
-                    shape=obs['agent_state'].shape,
-                    dtype=np.float32
+        self._observation_space = gym.spaces.Dict(
+            {
+                'agent_state': gym.spaces.Box(
+                    low=float("-inf"), high=float("inf"), shape=obs['agent_state'].shape, dtype=np.float32
                 ),
-            'global_state':
-                gym.spaces.Box(
-                    low=float("-inf"),
-                    high=float("inf"),
-                    shape=obs['global_state'].shape,
-                    dtype=np.float32
+                'global_state': gym.spaces.Box(
+                    low=float("-inf"), high=float("inf"), shape=obs['global_state'].shape, dtype=np.float32
                 ),
-        })
+            }
+        )
         self._action_space = gym.spaces.Dict({agent: self._env.action_space[agent] for agent in self._agents})
         single_agent_obs_space = self._env.action_space[self._agents[0]]
         if isinstance(single_agent_obs_space, gym.spaces.Box):
